#'---
#'title: "Figure 4A1: Rise in LFO Assessments Over Time "
#'author: "Michael Morse"
#'---
#+ message = F
rm(list = ls())
library(magrittr)
library(ggplot2)

#' # Load Data
#' This anonymized data comes from our sample of Alabama circuit court cases from 1995, 2000, and 2005–11. It is limited to cases where there is a valid court action and a felony conviction. 
data <- readRDS("Data_4A1.rds")

#' # Figure
#' Set up caption

caption <- paste0("Note: This box plot displays the total legal financial obligations assessed in cases that result in a felony conviction and are assessed more than the bail fee of $35 (n = ", format(nrow(data), big.mark = ",") , "). The y-axis is log-scaled.")
caption <- paste0(strwrap(caption, 140), sep="", collapse="\n")

g <-
  data %>%
  ggplot(aes(x = year, y = amount.due)) +
  geom_boxplot(varwidth = T, outlier.size = 1) +
  scale_y_log10(labels = scales::dollar_format(),
                breaks = c(50, 100, 1000, 10000, 100000)) +
  labs(y = "LFOs Assessed",
       x = "Year of Court Case",
       title = "Distribution of LFO Assessments by Year",
       caption = caption) +
  theme(plot.title = element_text(hjust = 0.5),
        plot.caption=element_text(hjust=0, margin=margin(t=15)),
        panel.background = element_blank(),
        axis.line.x =element_line(color="#2b2b2b", size=0.35),
        axis.line.y =element_line(color="#2b2b2b", size=0.35))

g

