#' ---
#' title: "Replicate Table 4B2: Alacourt Census"
#' author: "Michael Morse"
#' ---
#'
#+ warning = F, message = F, echo = F
rm(list = ls())
library(magrittr)
library(dplyr)
library(stringr)
library(readr)
library(knitr)
library(ggplot2)

#' # Load Alacourt data
#' There are five data frames, each stored as an element of the list. 
#' The first (felony_conviction_imposed_sent) cases with felony convictions and an imposed sentence.
#' The second (felony_conviction_no_imposed_sent) are cases with felony convictions but no imposed sentence.
#' The third (misdemeeanor_conviction_imposed_sent) are cases with a misdeamnor, but not a felony conviction, and an imposed sentence.
#' The fourt (misdemeanor_conviction_no_imposed_sent) are cases with a misdemeanor, but not a felony conviction, but no imposed sentence.
#' The fifth (dismissed_but_pos_lfos) are cases that were dismissed, with the top-coded charge type reported. 

data <- readRDS("Data_4B2.rds")

#' # Compute Table

#' ## For each of the five case-level groupings, I want to know the number of cases as well as the total amount due.

#' Write a function to get the values I want, so I can apply this repeatedly.
get_tbl_values <- function(df) {
  df %>%
    summarise(n = n(),
              total_due = sum(amount.due, na.rm = T))
}

fi <- get_tbl_values(data$felony_conviction_imposed_sent)
fni <- get_tbl_values(data$felony_conviction_no_imposed_sent)
mi <- get_tbl_values(data$misdemeanor_conviction_imposed_sent)
mni <- get_tbl_values(data$misdemeanor_conviction_no_imposed_sent)
d <- get_tbl_values(data$dismissed_but_pos_lfos)

type <- c("Felony Conviction, Sentence Imposed",
          "Felony Conviction, No Sentence Imposed",
          "Misdemeanor Conviction, Sentence Imposed",
          "Misdemeanor Conviction, No Sentence Imposed",
          "Dismissed Case, But Positive LFO Asseessment")

result <-
  bind_rows(fi, fni, mi, mni, d) %>%
  mutate(type = type)

result %>% kable()

#' For in-text empirics.
result$total_due[1] / sum(result$total_due)



